pub struct DataValue { /* private fields */ }Trait Implementations
Sourceimpl BorshDeserialize for DataValue
Available on crate feature borsh only.
impl BorshDeserialize for DataValue
Available on crate feature
borsh only.fn deserialize_reader<R>(reader: &mut R) -> Result<DataValue, Error>where
R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DataValue
Available on crate feature borsh only.
impl BorshSerialize for DataValue
Available on crate feature
borsh only.Sourceimpl Decode for DataValue
Available on crate feature parity-scale-codec only.
impl Decode for DataValue
Available on crate feature
parity-scale-codec only.Sourcefn decode<I>(input: &mut I) -> Result<DataValue, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<DataValue, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for DataValue
Available on crate feature serde only.
impl<'de> Deserialize<'de> for DataValue
Available on crate feature
serde only.Sourcefn deserialize<D>(
deserializer: D,
) -> Result<DataValue, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<DataValue, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for DataValue
Available on crate feature parity-scale-codec only.
impl Encode for DataValue
Available on crate feature
parity-scale-codec only.Sourcefn encode_to<T>(&self, writer: &mut T)
fn encode_to<T>(&self, writer: &mut T)
Convert self to a slice and append it to the destination.
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl Eq for DataValue
Sourceimpl JsonSchema for DataValue
Available on crate feature schema only.
impl JsonSchema for DataValue
Available on crate feature
schema only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DataValue
Available on crate feature serde only.
impl Serialize for DataValue
Available on crate feature
serde only.Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DataValue